Name:           libdasm
Version:        1.6
Summary:        Simple x86 disassembly library
%global         baserelease     16.1


%global         common_description %{expand:
libdasm is a C-library that tries to provide simple and convenient
way to disassemble Intel x86 raw op-code bytes (machine code).
It can parse and print out op-codes in AT&T and Intel syntax.

The op-codes are based on IA-32 Intel Architecture Software Developers
Manual Volume 2: Instruction Set Reference, order number 243667,
year 2004.  Non-Intel instructions are not supported at the moment (also,
non-Intel but Intel-compatible CPU extensions, like AMD 3DNow! are
not supported).}


%bcond_without  python3

%bcond_with     python2



License:        BSD
URL:            https://github.com/jtpereyda/libdasm




Patch1:         libdasm-01_readonly.patch

Patch2:         libdasm-02_explicit_python.patch

Patch3:         libdasm-03_das_futurize.patch

%{?filter_setup:
%filter_provides_in %{python2_sitearch}/.*\.so$
%filter_setup
}


%global         gituser         jtpereyda
%global         gitname         libdasm
%global         gitdate         20180330
%global         commit          b9233ccf35dce894ac0188e5830fa4346873a1f6
%global         shortcommit     %(c=%{commit}; echo ${c:0:7})


%global         build_release    1

Release:    1%{?dist}
Source0:        https://github.com/%{gituser}/%{gitname}/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz


BuildRequires:  make
BuildRequires:  gcc
BuildRequires:  pkgconfig
BuildRequires:  automake
BuildRequires:  libtool
BuildRequires:  gettext-devel
%if 0%{?with_python3}
BuildRequires:  python%{python3_pkgversion}-devel
BuildRequires:  python%{python3_pkgversion}-setuptools
%endif

%description 
%{common_description}


%package        devel
Summary:        Development files for %{name}
Requires:       %{name} = %{version}-%{release}

%description    devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.
%{common_description}



%if 0%{?with_python3}
%package        -n python%{python3_pkgversion}-pydasm
Summary:        Python module for disassembling x86 machine code
Requires:       %{name} = %{version}-%{release}
%{?python_provide:%python_provide python%{python3_pkgversion}-pydasm}


%description    -n python%{python3_pkgversion}-pydasm
The python%{python3_pkgversion} pydasm module for disassembling x86 machine code.
It is a python wrapper for libdasm.
%{common_description}

%endif




%prep
%if 0%{?build_release} > 0
%autosetup -p 1 -n %{gitname}-%{version}

%else
%autosetup -p 1 -n %{gitname}-%{commit}
%endif


rm -rf bin

sed -i -e 's|python |python2 |g;' pydasm/Makefile

sed -i -e 's|make -C pydasm|# make -C pydasm|' Makefile



%build
make %{?_smp_mflags} CFLAGS="%{optflags} -fPIC" PREFIX=/usr LIBDIR=%{_libdir} BINDIR=%{_bindir}

%if 0%{?with_python3}
pushd pydasm
%py3_build
popd
%endif



%install
make install DESTDIR=%{buildroot} PREFIX=/usr LIBDIR=%{_libdir} BINDIR=%{_bindir}
rm -f "%{buildroot}%{_bindir}/das.py"


%if 0%{?with_python3}
sed -i -e 's|^#!/usr/bin/.*|#!/usr/bin/python3|;' pydasm/das.py
pushd pydasm
%py3_install
install -m 755 -p -D das.py "%{buildroot}%{_bindir}/das-%{python3_version}"
pushd %{buildroot}%{_bindir}
ln -s "das-%{python3_version}" "das-3"
popd
popd
%endif


pushd %{buildroot}%{_bindir}
%if 0%{?with_python3}
    ln -s "das-3" "das.py"
%else
%if 0%{?with_python2}
    ln -s "das-2" "das.py"
%endif
%endif
popd

find %{buildroot} -name '*.la' -exec rm -f {} ';'
find %{buildroot} -name '*.a' -exec rm -f {} ';'




%files
%doc HISTORY.txt LIB.txt README.txt TODO.txt
%{_libdir}/*.so.*
%{_bindir}/das

%files devel
%{_includedir}/*
%{_libdir}/*.so

%if 0%{?with_python3}
%files -n python%{python3_pkgversion}-pydasm
%{python3_sitearch}/pydasm*
%{_bindir}/das-%{python3_version}
%{_bindir}/das-3
%{_bindir}/das.py
%endif


%changelog
* Wed Aug 14 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.6-1
- initial build
